C+
C NAME:
C	Time1Round
C PURPOSE:
C	Rounds 1-element standard time
C CATEGORY:
C	gen/for/lib
C CALLING SEQUENCE:
	subroutine Time1Round(hms,t,u)
C INPUTS:
C	hms(4)		integer
C	t		integer
C OUTPUTS:
C	u		integer
C CALLS:
C	Time1to2, Time2to1, Time2Round
C MODIFICATION HISTORY:
C	JAN-2004, Paul Hick (pphick@ucsd.edu)
C-
	    integer	hms(4)
	    integer	t
	    integer	u

	integer		v(2)

	call Time1to2(t,v)
	call Time2Round(hms,v,v)
	call Time2to1(v,u)

	return
	end
